@@ -298,6 +298,30 @@ def insert_to_sheet(
     if replace:
         sheet.clear()
 
+    # Check for current size of sheet
+    max_rows = len(sheet.get_all_values())
+    max_cols = len(sheet.get_all_values()[0])
+
+    # Check if required data output exceeds file boundaries
+    writing_to_max_row = (
+        data.shape[0] + sheet_offset[0] if sheet_offset else data.shape[0]
+    )
+    writing_to_max_col = (
+        data.shape[1] + sheet_offset[1] if sheet_offset else data.shape[1]
+    )
+
+    # Compute excess rows and columns
+    excess_rows = writing_to_max_row - max_rows
+    excess_cols = writing_to_max_col - max_cols
+
+    # (If required) add new rows/cols and reinitialize sheet (required)
+    if excess_rows > 0:
+        sheet.add_rows(excess_rows)
+        sheet = sheet_file.worksheet(params[f"gsheet_{mode}_sheet"])
+    if excess_cols > 0:
+        sheet.add_cols(excess_cols)
+        sheet = sheet_file.worksheet(params[f"gsheet_{mode}_sheet"])
+
     # Fill either a range of cells (as list) or the entire worksheet
     if sheet_offset:
         gspread_dataframe.set_with_dataframe(
