@@ -606,12 +606,10 @@ def kappa_analysis(params, data):
 def calculate_mean_average_precision(params, data):
     """Store mean average precision per category. Works for multiple categories."""
     results = {}
-    results["mAp_per_category"] = {}
-    results["pr_per_category"] = {}
-    results["rc_per_category"] = {}
-
-    # Plot curves per cn category
     if params["data_n_output"] > 1:
+        results = {"mAp_per_category": {}, "pr_per_category": {}, "rc_per_category": {}}
+
+        # Plot curves per category of the labels
         for label_cat in data["label_val"].columns:
             # Compute precision, recall, and mAp score
             results["mAp"] = average_precision_score(
@@ -635,13 +633,17 @@ def calculate_mean_average_precision(params, data):
         data["total_label"], data["total_pred"]
     )
 
+    # Convert to list from numpy array. Else, insert_to_metrics will throw an error.
+    results["mAp"] = np.round(results["mAp"], 4)
     results["pr"] = list(np.round(results["pr"], 4))
     results["rc"] = list(np.round(results["rc"], 4))
 
-    # Store the average score of all categories
-    results["mAp_per_category"]["Overall"] = np.round(results["mAp"], 4)
-    results["pr_per_category"]["Overall"] = list(np.round(results["pr"], 4))
-    results["rc_per_category"]["Overall"] = list(np.round(results["rc"], 4))
+    # Calculate the overall results if outputs are > 1
+    if params["data_n_output"] > 1:
+        # Store the average score of all categories
+        results["mAp_per_category"]["Overall"] = np.round(results["mAp"], 4)
+        results["pr_per_category"]["Overall"] = list(np.round(results["pr"], 4))
+        results["rc_per_category"]["Overall"] = list(np.round(results["rc"], 4))
 
     # Insert the score to logs
     msg = f"Average Precision: {results['mAp']:.4f}"
